changeset 1813:a8f3ef142271

(add-change-log-entry): Restrict PARAGRAPH-END to being on the first page.
author Roland McGrath <roland@gnu.org>
date Mon, 25 Jan 1993 17:05:57 +0000
parents 32248d533b4b
children e8a0d6a1b36a
files lisp/add-log.el
diffstat 1 files changed, 5 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/add-log.el	Mon Jan 25 16:59:48 1993 +0000
+++ b/lisp/add-log.el	Mon Jan 25 17:05:57 1993 +0000
@@ -112,10 +112,14 @@
 		"  " full-name
 		"  (" login-name "@" site-name ")\n\n"))
 
     ;; Search only within the first paragraph.
     (forward-paragraph 1)
     (setq paragraph-end (point))
     (goto-char (point-min))
+    (forward-page 1)
+    (if (< (point) paragraph-end)
+	(setq paragraph-end (point)))
+    (goto-char (point-min))
 
     ;; Now insert the new line for this entry.
     (cond ((re-search-forward "^\\s *\\*\\s *$" paragraph-end t)
@@ -112,10 +112,14 @@
 		"  (" login-name "@" site-name ")\n\n"))
 
-    ;; Search only within the first paragraph.
+    ;; Search only within the first paragraph of the first page.
     (forward-paragraph 1)
     (setq paragraph-end (point))